@@ -30,11 +30,11 @@ DBIx::Class::MooseColumns - Lets you write DBIC add_column() definitions as attr
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 
 =head1 SYNOPSIS
@@ -47,6 +47,8 @@ our $VERSION = '0.09';
 
   extends 'DBIx::Class::Core';
 
+  __PACKAGE__->table('artist');
+
   has id => (
     isa => 'Int',
     is  => 'rw',
@@ -75,7 +77,9 @@ our $VERSION = '0.09';
     is  => 'rw',
   );
 
-  __PACKAGE__->meta->make_immutable(inline_constructor => 0);
+  __PACKAGE__->set_primary_key('id');
+
+  __PACKAGE__->meta->make_immutable( inline_constructor => 0 );
 
   1;
 
@@ -93,6 +97,16 @@ L<Class::Accessor::Grouped>-generated accessor methods under the hood) with the
 L<Moose>-generated accessor methods so that you can use more of the wonderful
 powers of L<Moose> (eg. type constraints, triggers, ...).
 
+I<Note:> C<< __PACKAGE__->table(...) >> must go B<before> the C<has> stanzas
+(the L<DBIx::Class::ResultSource/table> is magic and does much more than
+setting the table name, thus the C<< __PACKAGE__->add_column(...) >> calls that
+the C<has> triggers won't work before that).
+
+I<Note:> C<< __PACKAGE__->set_primary_key(...) >> and C<<
+__PACKAGE__->add_unique_constraint(...) >> calls must go B<after> the C<has>
+stanzas (since they depend on the referred columns being registered via C<<
+__PACKAGE__->add_column(...) >> and that call is done when the C<has> runs).
+
 =head1 SEE ALSO
 
 L<DBIx::Class>, L<Moose>
