@@ -50,7 +50,7 @@ around _inline_store => sub {
   if ($attr->has_dbix_class_moosecolumns_column_info) {
     my ($slot_name) = $attr->slots;
 
-    return sprintf q[%s->%s("%s", "%s")], $instance,
+    return sprintf q[%s->%s("%s", %s)], $instance,
       ($attr->is_dbix_class_moosecolumns_inflated_column
         ? 'set_inflated_column' : 'set_column'),
       quotemeta($slot_name), $value;
